@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id: package.lisp 10227 2004-12-27 03:46:01Z kevin $
+;;;; $Id: package.lisp 10470 2005-04-26 21:46:09Z kevin $
 ;;;;
 ;;;; This file, part of KMRCL, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
@@ -146,7 +146,9 @@
    #:histogram
    #:fixnum-width
    #:scaled-epsilon
-   
+   #:sinc
+   #:numbers-within-percentage
+
    ;; macros.lisp
    #:time-iterations
    #:time-seconds
