@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  June 2003
 ;;;;
-;;;; $Id: processes.lisp 10152 2004-11-11 21:58:28Z kevin $
+;;;; $Id: processes.lisp 10361 2005-03-19 21:40:21Z kevin $
 ;;;; *************************************************************************
 
 (in-package #:kmrcl)
@@ -46,7 +46,7 @@
   #+lispworks
   `(mp:with-lock (,lock) ,@body)
   #+sb-thread
-  `(sb-thread:with-mutex (,lock) ,@body)
+  `(sb-thread:with-recursive-lock (,lock) ,@body)
   #+openmcl
   `(ccl:with-lock-grabbed (,lock) ,@body)
   #-(or allegro cmu lispworks sb-thread openmcl)
