@@ -7,7 +7,7 @@
 ;;;; Author:        Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2003
 ;;;;
-;;;; $Id: tests.lisp 9992 2004-09-10 09:02:03Z kevin $
+;;;; $Id: tests.lisp 10504 2005-04-30 10:14:18Z kevin $
 ;;;;
 ;;;; This file is Copyright (c) 2000-2002 by Kevin M. Rosenberg
 ;;;;
@@ -396,7 +396,15 @@
 (deftest :unique.2
     (unique-slot-values nil 'a)
   nil)
-     
+
+(deftest :nwp.1     
+       (numbers-within-percentage 1. 1.1 9)
+  nil)
+
+(deftest :nwp.2
+       (numbers-within-percentage 1. 1.1 11)
+  t)
+  
 	   
  ;;; MOP Testing
 
